==> owncloud_3.0.0.orig.tar.bz2: owncloud/lib/mimetypes.list.php <==
<?php
/**
* ownCloud
*
* @author Robin Appelman
* @copyright 2011 Robin Appelman icewind1991@gmail.com
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
* License as published by the Free Software Foundation; either
* version 3 of the License, or any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU AFFERO GENERAL PUBLIC LICENSE for more details.
*
* You should have received a copy of the GNU Affero General Public
* License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*
*/

/**
 * list of mimetypes by extention
 */

return array(
	'css'=>'text/css',
	'flac'=>'audio/flac',
	'gif'=>'image/gif',
	'gzip'=>'application/x-gzip',
	'gz'=>'application/x-gzip',
	'html'=>'text/html',
	'htm'=>'text/html',
	'ics'=>'text/calendar',
	'ical'=>'text/calendar',
	'jpeg'=>'image/jpeg',
	'jpg'=>'image/jpeg',
	'js'=>'application/javascript',
	'oga'=>'audio/ogg',
	'ogg'=>'audio/ogg',
	'ogv'=>'video/ogg',
	'pdf'=>'application/pdf',
	'png'=>'image/png',
	'svg'=>'image/svg+xml',
	'tar'=>'application/x-tar',
	'tgz'=>'application/x-compressed',
	'tar.gz'=>'application/x-compressed',
	'tif'=>'image/tiff',
	'tiff'=>'image/tiff',
	'txt'=>'text/plain',
	'zip'=>'application/zip',
	'wav'=>'audio/wav',
	'odt'=>'application/vnd.oasis.opendocument.text',
	'ods'=>'application/vnd.oasis.opendocument.spreadsheet',
	'odg'=>'application/vnd.oasis.opendocument.graphics',
	'odp'=>'application/vnd.oasis.opendocument.presentation',
	'kra'=>'application/x-krita',
	'mp3'=>'audio/mpeg',
	'doc'=>'application/msword',
	'docx'=>'application/msword',
	'xls'=>'application/msexcel',
	'xlsx'=>'application/msexcel',
	'php'=>'application/x-php',
	'exe'=>'application/x-ms-dos-executable',
	'pl'=>'application/x-pearl',
	'py'=>'application/x-python',
	'blend'=>'application/x-blender',
	'xcf'=>'application/x-gimp',
	'psd'=>'application/x-photoshop',
	'xml'=>'application/xml',
	'avi'=>'video/x-msvideo',
	'dv'=>'video/dv',
	'm2t'=>'video/mp2t',
	'mp4'=>'video/mp4',
	'm4v'=>'video/mp4',
	'mpg'=>'video/mpeg',
	'mpeg'=>'video/mpeg',
	'mov'=>'video/quicktime',
	'webm'=>'video/webm',
	'wmv'=>'video/x-ms-asf'
);

==> owncloud-4.0.7.tar.bz2: owncloud/lib/mimetypes.list.php <==
<?php
/**
* ownCloud
*
* @author Robin Appelman
* @copyright 2011 Robin Appelman icewind1991@gmail.com
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
* License as published by the Free Software Foundation; either
* version 3 of the License, or any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU AFFERO GENERAL PUBLIC LICENSE for more details.
*
* You should have received a copy of the GNU Affero General Public
* License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*
*/

/**
 * list of mimetypes by extension
 */

return array(
	'css'=>'text/css',
	'flac'=>'audio/flac',
	'gif'=>'image/gif',
	'gzip'=>'application/x-gzip',
	'gz'=>'application/x-gzip',
	'html'=>'text/html',
	'htm'=>'text/html',
	'ics'=>'text/calendar',
	'ical'=>'text/calendar',
	'jpeg'=>'image/jpeg',
	'jpg'=>'image/jpeg',
	'js'=>'application/javascript',
	'oga'=>'audio/ogg',
	'ogg'=>'audio/ogg',
	'ogv'=>'video/ogg',
	'pdf'=>'application/pdf',
	'png'=>'image/png',
	'svg'=>'image/svg+xml',
	'tar'=>'application/x-tar',
	'tgz'=>'application/x-compressed',
	'tar.gz'=>'application/x-compressed',
	'tif'=>'image/tiff',
	'tiff'=>'image/tiff',
	'txt'=>'text/plain',
	'zip'=>'application/zip',
	'wav'=>'audio/wav',
	'odt'=>'application/vnd.oasis.opendocument.text',
	'ods'=>'application/vnd.oasis.opendocument.spreadsheet',
	'odg'=>'application/vnd.oasis.opendocument.graphics',
	'odp'=>'application/vnd.oasis.opendocument.presentation',
	'kra'=>'application/x-krita',
	'mp3'=>'audio/mpeg',
	'doc'=>'application/msword',
	'docx'=>'application/msword',
	'xls'=>'application/msexcel',
	'xlsx'=>'application/msexcel',
	'php'=>'application/x-php',
	'exe'=>'application/x-ms-dos-executable',
	'pl'=>'application/x-pearl',
	'py'=>'application/x-python',
	'blend'=>'application/x-blender',
	'xcf'=>'application/x-gimp',
	'psd'=>'application/x-photoshop',
	'xml'=>'application/xml',
	'avi'=>'video/x-msvideo',
	'dv'=>'video/dv',
	'm2t'=>'video/mp2t',
	'mp4'=>'video/mp4',
	'm4v'=>'video/mp4',
	'mpg'=>'video/mpeg',
	'mpeg'=>'video/mpeg',
	'mov'=>'video/quicktime',
	'webm'=>'video/webm',
	'wmv'=>'video/x-ms-asf'
);
